@@ -9,7 +9,6 @@ import com.badlogic.gdx.scenes.scene2d.ui.Table
 import com.badlogic.gdx.scenes.scene2d.utils.ChangeListener
 import com.badlogic.gdx.utils.Array
 import com.unciv.GUI
-import com.unciv.ui.screens.mainmenuscreen.MainMenuScreen
 import com.unciv.UncivGame
 import com.unciv.logic.event.EventBus
 import com.unciv.models.UncivSound
@@ -20,15 +19,16 @@ import com.unciv.models.metadata.SettingsPropertyChanged
 import com.unciv.models.metadata.SettingsPropertyUncivSoundChanged
 import com.unciv.models.ruleset.RulesetCache
 import com.unciv.models.translations.tr
-import com.unciv.ui.images.ImageGetter
-import com.unciv.ui.popups.Popup
-import com.unciv.ui.screens.basescreen.BaseScreen
 import com.unciv.ui.components.TabbedPager
 import com.unciv.ui.components.extensions.center
 import com.unciv.ui.components.extensions.onChange
 import com.unciv.ui.components.extensions.toCheckBox
 import com.unciv.ui.components.extensions.toGdxArray
 import com.unciv.ui.components.extensions.toLabel
+import com.unciv.ui.images.ImageGetter
+import com.unciv.ui.popups.Popup
+import com.unciv.ui.screens.basescreen.BaseScreen
+import com.unciv.ui.screens.mainmenuscreen.MainMenuScreen
 import com.unciv.ui.screens.worldscreen.WorldScreen
 import com.unciv.utils.concurrency.Concurrency
 import com.unciv.utils.concurrency.withGLContext
@@ -169,12 +169,13 @@ class OptionsPopup(
         else table.add(checkbox).left()
     }
 
-    fun addCheckbox(table: Table,
-                    text: String,
-                    settingsProperty: KMutableProperty0<Boolean>,
-                    updateWorld: Boolean = false,
-                    newRow: Boolean = true,
-                    action: (Boolean) -> Unit = {}) {
+    fun addCheckbox(
+        table: Table,
+        text: String,
+        settingsProperty: KMutableProperty0<Boolean>,
+        updateWorld: Boolean = false,
+        action: (Boolean) -> Unit = {}
+    ) {
         addCheckbox(table, text, settingsProperty.get(), updateWorld) {
             action(it)
             settingsProperty.set(it)
